import configparser

config = configparser.ConfigParser()
if not config.read(
        filenames="./config.ini",
        encoding="utf-8"):
    config["values.common"] = {"reserved": "reserved"}
    config["values.prefix"] = {"kilo": "k"}
    config["values.enum"] = {
        "time_year": "a",
        "time_month": "mo",
        "time_week": "wk",
        "time_day": "d",
        "time_hour": "h",
        "time_minute": "min",
        "time_second": "s",
        "phase_angle_degree": "°",
        "temperature": "°c",
        "local_currency": "currency",
        "length_metre": "m",
        "speed_metre_per_second": "m / s",
        "volume_value_cubic_metre": "m³",
        "corrected_volume_cubic_metre": "m³ *",
        "volume_flux_cubic_metre_per_hour": "m³ / h",
        "corrected_volume_flux_cubic_metre_per_hour": "m³ / h *",
        "volume_flux_cubic_metre_per_day": "m³ / d",
        "corrected_volume_flux_cubic_metre_per_day": "m³ / d",
        "volume_litre": "l",
        "mass_kilogram": "kg",
        "force_newton": "n",
        "energy_newton_meter": "nm",
        "pressure_pascal": "pa",
        "pressure_bar": "bar",
        "energy_joule": "j",
        "thermal_power_rate_of_change_joule_per_hour": "j / h",
        "active_power_watt": "w",
        "apparent_power_volt_ampere": "va",
        "reactive_power_var": "var",
        "active_energy_value_watt_hour": "wh",
        "apparent_energy_value_volt_ampere_hour": "vah",
        "reactive_energy_value_var_hour": "varh",
        "current_ampere": "a",
        "electrical_charge_coulomb": "c",
        "voltage_volt": "v",
        "electric_field_strength_volt_per_metre": "v / m",
        "capacitance_farad": "f",
        "resistance_ohm": "ω",
        "resistivity": "ωm² / m",
        "magnetic_flux_weber": "wb",
        "magnetic_flux_density_tesla": "t",
        "magnetic_field_strength_ampere_per_metre": "a / m",
        "inductance_henry": "h",
        "frequency_hertz": "hz",
        "rw_active_energy_value": "1 / (wh)",
        "rb_reactive_energy_value": "1 / (varh)",
        "rs_apparent_energy_value": "1 / (vah)",
        "volt_squared_hour_volt_squared_hour_meter": "v²h",
        "ampere_squared_hour": "a²h",
        "mass_flux_kilogram_per_second": "kg / s",
        "conductance_siemens": "s, mho",
        "temperature_kelvin": "k",
        "ru2h_volt_squared_hour_meter": "1 / (v²h)",
        "ri2h_ampere_squared_hour_meter": "1 / (a²h)",
        "rv_meter": "1 / m³",
        "percentage": "%%",
        "ampere_hours": "ah",
        "energy_per_volume": "wh / m³",
        "calorific_value_wobbe": "j / m³",
        "molar_fraction_of_gas_composition_mole_percent": "mol %%",
        "mass_density_quantity_of_material": "g / m³",
        "dynamic_viscosity_pascal_second": "pa s",
        "specific_energy_joule_kilogram": "j / kg",
        "pressure_gram_per_square_centimeter": "g / cm²",
        "pressure_atmosphere": "atm",
        "signal_strength_milliwatt": "dbm",
        "signal_strength_microvolt": "dbµv",
        "logarithmic_unit": "db",
        "length_inch": "in",
        "length_foot": "ft",
        "mass_pound": "lb",
        "temperature_fahrenheit": "°f",
        "temperature_rankine": "°r",
        "area_square_inch": "sq. in",
        "area_square_foot": "sq ft",
        "area_acre": "ac",
        "volume_cubic_inch": "cu in",
        "volume_cubic_foot": "cu ft",
        "volume_acre_foot": "ac ft",
        "volume_gallon_imperial": "gal(imp)",
        "volume_gallon_us": "gal(us)",
        "force_pound_force": "lbf",
        "pressure_pound_force_per_square_inch": "psi",
        "density_pound_per_cubic_foot": "lb / cu ft",
        "dynamic_viscosity": "lb / (ft.s)",
        "kinematic_viscosity_square_foot_per_second": "sq ft / s",
        "energy_british_thermal_unit": "btu",
        "energy_therm_eu": "thm(ec)",
        "energy_therm_us": "thm(us)",
        "calorific_value_of_mass_lenthalpy": "btu / lb",
        "calorific_value_of_volume_wobbe": "btu / cu ft",
        "volume_meter_cubic_feet_rv": "cu ft rv",
        "speed_foot_per_second": "ft / s",
        "volume_flux_cubic_foot_per_second": "cu ft/s",
        "volume_flux_cubic_foot_per_min": "cu ft/min",
        "volume_flux_cubic_foot_per_hour": "cu ft/h",
        "volume_flux_cubic_foot_per_day": "cu ft/d",
        "volume_flux_acre_foot_per_second": "ac ft/s",
        "volume_flux_acre_foot_per_min": "ac ft/min",
        "volume_flux_acre_foot_per_hour": "ac ft/h",
        "volume_flux_acre_foot_per_day": "ac ft/d",
        "volume_imperial_gallon_meter_rv": "gal(imp) rv",
        "volume_flux_imperial_gallon_per_second": "gal(imp) / s",
        "volume_flux_imperial_gallon_per_min": "gal(imp) / min",
        "volume_flux_imperial_gallon_per_hour": "gal(imp) / h",
        "volume_flux_imperial_gallon_per_day": "gal(imp) / d",
        "volume_us_gallon_rv": "gal(us) rv",
        "volume_flux_us_gallon_per_second": "gal(us) / s",
        "volume_flux_us_gallon_per_min": "gal(us) / min",
        "volume_flux_us_gallon_per_hour": "gal(us) / h",
        "volume_flux_us_gallon_per_day": "gal(us) / d",
        "energy_flow_british_thermal_unit_per_second": "btu / s",
        "energy_flow_british_thermal_unit_per_minute": "btu / min",
        "energy_flow_british_thermal_unit_per_hour": "btu / h",
        "energy_flow_british_thermal_unit_per_day": "btu / d",
        "extended_table_of_units": "extended",
        "other_unit": "other",
        "no_unit_unitless_count": "count}"}



OPTICAL_PORT = "Optical port"
RS485 = "RS-485"
TCP_IP = "TCP/IP"
NOT_DEFINED = "not defined"
INTERNAL_CRYSTAL = "internal crystal"
MAINS_FREQUENCY_50_HZ = "mains frequency 50 Hz"
MAINS_FREQUENCY_60_HZ = "mains frequency 60 Hz"
GPS_GLOBAL_POSITIONING_SYSTEM = "GPS (global positioning system)"
RADIO_CONTROLLED = "radio controlled"
CONTROL_MODE_0 = "None. The disconnect control object is always in <connected> state"
CONTROL_MODE_1 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(d), manual(e)"
CONTROL_MODE_2 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(a), manual(e)"
CONTROL_MODE_3 = "Disconnection: remote(b, c), local(g) Reconnection: Remote(d), manual(e)"
CONTROL_MODE_4 = "Disconnection: remote(b, c), local(g) Reconnection: Remote(a), manual(e)"
CONTROL_MODE_5 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(d), manual(e), local(h)"
CONTROL_MODE_6 = "Disconnection: remote(b, c), local(g) Reconnection: remote(d), manual(e), local(h)"
RU_CONTROL_MODE_129 = "Disconnection: remote(b, c), manual(f), local(m) Reconnection: remote(d), manual(e)"
RU_CONTROL_MODE_130 = "Disconnection: remote(b, c), manual(f), local(m) Reconnection: remote(a), manual(e)"
RU_CONTROL_MODE_131 = "Disconnection: remote(b, c), local(m) Reconnection: remote(d), manual(e)"
RU_CONTROL_MODE_132 = "Disconnection: remote(b, c), local(m) Reconnection: remote(a)"
RU_CONTROL_MODE_133 = "Disconnection: remote(b, c), local(m) Reconnection: remote(a), local(k)"
RU_CONTROL_MODE_134 = "Disconnection: remote(b, c), local(m, s) Reconnection: remote(d), manual(e), local(p)"
DISCONNECTED = "Disconnected"
CONNECTED = "Connected"
READY_FOR_RECONNECTION = "Ready for reconnection"
NOT_REGISTERED = "not registered"
REGISTERED_HOME_NETWORK = "registered, home network"
NOT_REGISTERED_BUT_MT = "not registered, but MT is currently searching a new operator to register to"
REGISTRATION_DENIED = "registration denied"
UNKNOWN = "unknown"
REGISTERED_ROAMING = "registered, roaming"
INACTIVE = "inactive"
INCOMING_CALL = "incoming call"
ACTIVE = "active"
GPRS = "GPRS"
EDGE = "EDGE"
UMTS = "UMTS"
HSDPA = "HSDPA"
BAUD_300 = "300 baud"
BAUD_600 = "600 baud"
BAUD_1200 = "1200 baud"
BAUD_2400 = "2400 baud"
BAUD_4800 = "4800 baud"
BAUD_9600 = "9600 baud"
BAUD_19200 = "19200 baud"
BAUD_38400 = "38400 baud"
BAUD_57600 = "57600 baud"
BAUD_115200 = "115200 baud"
IMAGE_TRANSFER_NOT_INITIATED = "Image transfer not initiated"
IMAGE_TRANSFER_INITIATED = "Image transfer initiated"
IMAGE_VERIFICATION_INITIATED = "Image verification initiated"
IMAGE_VERIFICATION_SUCCESSFUL = "Image verification successful"
IMAGE_VERIFICATION_FAILED = "Image verification failed"
IMAGE_ACTIVATION_INITIATED = "Image activation initiated"
IMAGE_ACTIVATION_SUCCESSFUL = "Image activation successful"
IMAGE_ACTIVATION_FAILED = "Image activation failed"
FIFO = "fifo (first in first out)"
LIFO = "lifo (last in first out)"
LARGEST = "largest"
SMALLEST = "smallest"
NEAREST_TO_ZERO = "nearest to zero"
FAREST_FROM_ZERO = "farest from zero"
WRITE_ATTRIBUTE = "write attribute"
EXECUTE_SPECIFIC_METHOD = "execute specific method"
SCHEDULE_TYPE_1 = "size of execution time = 1; wildcard in date allowed"
SCHEDULE_TYPE_2 = "size of execution time = n; all time values are the same, wildcard in date not allowed"
SCHEDULE_TYPE_3 = "size of execution time = n; all time values are the same, wildcard in date are allowed"
SCHEDULE_TYPE_4 = "size of execution time = n; time values may be different, wildcard in date not allowed"
SCHEDULE_TYPE_5 = "size of execution time = n; time values may be different, wildcard in date are allowed"
NO_ACCESS = "no access"
READ_ONLY = "read only"
WRITE_ONLY = "write only"
READ_AND_WRITE = "read and write"
NON_ASSOCIATED = "non associated"
ASSOCIATION_PENDING = "association pending"
ASSOCIATED = "associated"
NO_STATION = "no station"
CLIENT_MANAGEMENT_PROCESS = "Client Management Process"
PUBLIC_CLIENT = "Public client"
METER_READER = "Meter Reader"
UTILITY_SETTING = "Utility Settings"
PUSH = "Push"
FIRMWARE_UPDATE = "Firmware Update"
IHD = "IHD"
NONE = "NONE"
LOW = "LOW"
HIGH = "HIGH"
HIGH_MD5 = "HIGH MD5"
HIGH_SHA1 = "HIGH SHA1"
HIGH_GMAC = "HIGH GMAC"
HIGH_SHA256 = "HIGH SHA256"
HIGH_ECDSA = "HIGH ECDSA"
ACCESS = "access"
AUTHENTICATED_ACCESS = "authenticated_access"
NOTHING = "nothing"
ALL_MESSAGES_TO_BE_AUTHENTICATION = "all messages to be authentication"
ALL_MESSAGES_TO_BE_ENCRYPTED = "all messages to be encrypted"
ALL_MESSAGES_TO_BE_AUTH_AND_ENC = "all messages to be authentication and encrypted"
RESERVED = "reserved"
AUTHENTICATION_REQUEST = "authentication request"
ENCRYPTION = "encryption"
AUTHENTICATION_AND_ENCRYPTION = "authentication and encryption"
DIGITAL_SIGNATURE = "digital signature"
ENCRYPTED_REQUEST = "encrypted request"
DIGITALLY_SIGNED_REQUEST = "digitally signed request"
AUTHENTICATION_RESPONSE = "authentication response"
ENCRYPTED_RESPONSE = "encrypted response"
DIGITALLY_SIGNED_RESPONSE = "digitally signed response"
UNUSED = "unused, shall be set 0"
AUTHENTICATION = "authentication"
AUTHENTICATION_READ_ONLY = "authenticated_read_only"
AUTHENTICATION_WRITE_ONLY = "authenticated_write_only"
AUTHENTICATION_READ_AND_WRITE = "authenticated_read_and_write"
GUEK = "global unicast encryption key"
GBEK = "global broadcast encryption key"
GAK = "authentication key"
KEK = "master key"
AES_GCM_128 = "AES-GCM-128 for authenticated encryption and AES-128 for key wrapping"
AES_GCM_128_ECDSA_P_256 = "AES-GCM-128 authenticated encryption, ECDSA P-256 digital signature, ECDH P-256 key agreement, SHA-256 hash, V.44 compression and AES-128 key wrap"
AES_GCM_256_ECDSA_P_384 = "AES-GCM-256 authenticated encryption, ECDSA P-384 digital signature, ECDH P-384 key agreement, SHA-384 hash, V.44 compression and AES-256 key wrap"
SERVER = "server"
CLIENT_OR_THIRD_PARTY = "client or third party"
CERTIFICATION_AUTHORITY = "certification authority"
OTHER = "other"
KEY_AGREEMENT = "key agreement"
TLS = "TLS"
DIGITAL_SIGNATURE_KEY_PAIR = "digital signature key pair"
KEY_AGREEMENT_KEY_PAIR = "key agreement key pair"
TLS_KEY_PAIR = "tls key pair"
CERTIFICATE_IDENTIFICATION_ENTITY = "certificate identification entity"
CERTIFICATE_IDENTIFICATION_SERIAL = "certificate identification serial"
RESTRICTION_BY_DATE = "restriction by date"
RESTRICTION_BY_ENTRY = "restriction by entry"
TCP = "TCP"
UDP = "UDP"
FTP_RESERVED = "reserved for FTP"
SMTP_RESERVED = "reserved for SMTP"
SMS = "SMS"
HDLC = "HDLC"
M_BUS = "M_BUS"
ZIGBEE_RESERVED = "reserved for ZIGBEE"
DLMS_GATEWAY = "DLMS Gateway"
MANUFACTURER_SPECIFIC = "Manufacturer specific"
A_XDR = "A-XDR encoded xDLMS APDU"
XML = "XML encoded xDLMS APDU"
UNCONFIRMED_FAILURE = "unconfirmed, retry on supporting protocol layer failure"
UNCONFIRMED_MISSING = "unconfirmed, retry on missing supporting protocol layer confirmation"
CONFIRMED = "confirmed, retry on missing confirmation"
MASTER_KEY = "master key"
GLOB_UNI_ENCR_KEY = "global unicast encryption key"
GLOB_BROAD_ENCR_KEY = "global broadcast encryption key"
IDENTIFIED_KEY = "identified key"
WRAPPED_KEY = "wrapped key"
AGREED_KEY = "agreed key"

# for GSM_diagnostic.cell_info
OR_LESS = "or less"
OR_GREATER = "or greater"
NOT_KNOWN_OR_NOT_DETECTABLE = "not known or not detectable"



OPTICAL_PORT = "Оптический порт"
RS485 = "RS-485"
TCP_IP = "TCP/IP"
NOT_DEFINED = "не определен"
INTERNAL_CRYSTAL = "внутренний кварцевый генератор"
MAINS_FREQUENCY_50_HZ = "от сети 50 Гц"
MAINS_FREQUENCY_60_HZ = "от сети 60 Гц"
GPS_GLOBAL_POSITIONING_SYSTEM = "от системы GPS (GLONASS)"
RADIO_CONTROLLED = "от радиосигналов точного времени"
CONTROL_MODE_0 = "Отсутствует. Объект управления разъединением всегда находится в состоянии «подключено»"
CONTROL_MODE_1 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(D), ручной(E)"
CONTROL_MODE_2 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(A), ручной(E)"
CONTROL_MODE_3 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(D), ручной(E)"
CONTROL_MODE_4 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(A), ручной(E)"
CONTROL_MODE_5 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(D), ручной(E), локальный(H)"
CONTROL_MODE_6 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(D), ручной(E), локальный(H)"
RU_CONTROL_MODE_129 = "Отключение: удаленные(B, C), ручной(F), локальный(M) Переподключение: удаленный(D), ручной(E)"
RU_CONTROL_MODE_130 = "Отключение: удаленные(B, C), ручной(F), локальный(M) Переподключение: удаленный(A), ручной(E)"
RU_CONTROL_MODE_131 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(D), ручной(E)"
RU_CONTROL_MODE_132 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(A)"
RU_CONTROL_MODE_133 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(A), локальный(K)"
RU_CONTROL_MODE_134 = "Отключение: удаленные(B, C), локальный(M, S) Переподключение: удаленный(D), ручной(E), локальный(P)"
DISCONNECTED = "отключено"
CONNECTED = "включено"
READY_FOR_RECONNECTION = "Готово к переподключению"
NOT_REGISTERED = "не зарегистрирован"
REGISTERED_HOME_NETWORK = "зарегистрирован, домашняя сеть"
NOT_REGISTERED_BUT_MT = "не зарегистрирован, но MT в настоящее время ищет нового оператора для регистрации в"
REGISTRATION_DENIED = "регистрация отвергнута"
UNKNOWN = "неизвестно"
REGISTERED_ROAMING = "зарегистрирован, роуминг"
INACTIVE = "не aктивно"
INCOMING_CALL = "входящий звонок"
ACTIVE = "активно"
GPRS = "GPRS"
EDGE = "EDGE"
UMTS = "UMTS"
HSDPA = "HSDPA"
BAUD_300 = "300 бод"
BAUD_600 = "600 бод"
BAUD_1200 = "1200 бод"
BAUD_2400 = "2400 бод"
BAUD_4800 = "4800 бод"
BAUD_9600 = "9600 бод"
BAUD_19200 = "19200 бод"
BAUD_38400 = "38400 бод"
BAUD_57600 = "57600 бод"
BAUD_115200 = "115200 бод"
IMAGE_TRANSFER_NOT_INITIATED = "Передача данных не инициированна"
IMAGE_TRANSFER_INITIATED = "Передача данных инициированна"
IMAGE_VERIFICATION_INITIATED = "Проверка данных инициированна"
IMAGE_VERIFICATION_SUCCESSFUL = "Проверка данных пройдена"
IMAGE_VERIFICATION_FAILED = "Проверка данных неудачна"
IMAGE_ACTIVATION_INITIATED = "Активация данных инициированна"
IMAGE_ACTIVATION_SUCCESSFUL = "Активация данных пройдена"
IMAGE_ACTIVATION_FAILED = "Активация данных неудачна"
FIFO = "FIFO(первый пришел первый ушел)"
LIFO = "LIFO(последний пришел первый ушел)"
LARGEST = "наибольший"
SMALLEST = "наименьший"
NEAREST_TO_ZERO = "ближайший к нулю"
FAREST_FROM_ZERO = "дальний от нуля"
WRITE_ATTRIBUTE = "запись в атрибут"
EXECUTE_SPECIFIC_METHOD = "выполнить конкретный метод"
SCHEDULE_TYPE_1 = "Размер времени выполнения = 1; Подстановочный знак в дате разрешен"
SCHEDULE_TYPE_2 = "Размер времени выполнения = N; Все значения времени одинаковы, подстановочный знак на дате не допускается"
SCHEDULE_TYPE_3 = "Размер времени выполнения = N; Все значения времени одинаковы, подстановочный знак в дате разрешены"
SCHEDULE_TYPE_4 = "Размер времени выполнения = N; Значения времени могут быть разными, подстановочный знак даты не допускается"
SCHEDULE_TYPE_5 = "Размер времени выполнения = N; Значения времени могут быть разными, подстановочные знаки в дате разрешены"
NO_ACCESS = "нет доступа"
READ_ONLY = "только чтение"
WRITE_ONLY = "только запись"
READ_AND_WRITE = "чтение и запись"
NON_ASSOCIATED = "нет соединения"
ASSOCIATION_PENDING = "ожидание соединения"
ASSOCIATED = "соединение установлено"
NO_STATION = "Отсутствует"
CLIENT_MANAGEMENT_PROCESS = "Процесс управления клиентами"
PUBLIC_CLIENT = "Публичный клиент"
METER_READER = "Считыватель показаний"
UTILITY_SETTING = "Конфигуратор"
PUSH = "Инициативный"
FIRMWARE_UPDATE = "Обновление ПО"
IHD = "Домашний дисплей"
NONE = "Низший, без секретности"
LOW = "Низкий, без шифрования с паролем"
HIGH = "Высокий"
HIGH_MD5 = "Высокий, MD5"
HIGH_SHA1 = "Высокий, SHA1"
HIGH_GMAC = "Высокий, GMAC"
HIGH_SHA256 = "Высокий, SHA256"
HIGH_ECDSA = "Высокий, ECDSAL"
ACCESS = "доступно"
AUTHENTICATED_ACCESS = "доступ с проверкой подлинности"
NOTHING = "ничего не делать"
ALL_MESSAGES_TO_BE_AUTHENTICATION = "Все сообщения должны быть аутентифицированы"
ALL_MESSAGES_TO_BE_ENCRYPTED = "Все сообщения должны быть зашифрованы"
ALL_MESSAGES_TO_BE_AUTH_AND_ENC = "Все сообщения должны быть аутентифицированы и зашифрованы"
RESERVED = "зарезервировано"
AUTHENTICATION = "аутентификация"
AUTHENTICATION_REQUEST = "запрос с аутентификацией"
ENCRYPTION = "Шифрование"
AUTHENTICATION_AND_ENCRYPTION = "Аутентификация и шифрование"
DIGITAL_SIGNATURE = "Цифровая подпись"
ENCRYPTED_REQUEST = "зашифрованный запрос"
DIGITALLY_SIGNED_REQUEST = "запрос с цифровой подписью"
AUTHENTICATION_RESPONSE = "ответ с аутентификацией"
ENCRYPTED_RESPONSE = "зашифрованный ответ"
DIGITALLY_SIGNED_RESPONSE = "ответ с цифровой подписью"
UNUSED = "не используется, всегда 0"
AUTHENTICATION_READ_ONLY = "только чтение с проверкой подлинности"
AUTHENTICATION_WRITE_ONLY = "только запись с проверкой подлинности"
AUTHENTICATION_READ_AND_WRITE = "чтение и запись с проверкой подлинности"
GUEK = "Глобальный одноадресный ключ шифрования"
GBEK = "Глобальный широковещательный ключ шифрования"
GAK = "Ключ аутентификации"
KEK = "Мастер ключ"
AES_GCM_128 = "AES-GSM-128 аутентификация, шифрование и упаковка ключей"
AES_GCM_128_ECDSA_P_256 = "AES-GSM-128 аутентификация, шифрование, цифровая подпись, согласование ключей, хеширование, V.44 сжатие и упаковка ключей"
AES_GCM_256_ECDSA_P_384 = "AES-GSM-256 аутентификация, шифрование, цифровая подпись, согласование ключей, хеширование, V.44 сжатие и упаковка ключей"
SERVER = "Сервер"
CLIENT_OR_THIRD_PARTY = "Клиент"
CERTIFICATION_AUTHORITY = "Администратор"
OTHER = "Прочее"
KEY_AGREEMENT = "Соглосование ключей"
TLS = "TLS"
DIGITAL_SIGNATURE_KEY_PAIR = F"{DIGITAL_SIGNATURE} пары ключей"
KEY_AGREEMENT_KEY_PAIR = "Соглосование пары ключей"
TLS_KEY_PAIR = "TLS пары ключей"
CERTIFICATE_IDENTIFICATION_ENTITY = "Идентификация сертификата по объекту"
CERTIFICATE_IDENTIFICATION_SERIAL = "Идентификация сертификата по серийному номеру"
RESTRICTION_BY_DATE = "Ограничение по дате"
RESTRICTION_BY_ENTRY = "Ограничение по входу"
TCP = "TCP"
UDP = "UDP"
FTP_RESERVED = "зарезервированно для FTP"
SMTP_RESERVED = "зарезервированно для SMTP"
SMS = "SMS"
HDLC = "HDLC"
M_BUS = "M_BUS"
ZIGBEE_RESERVED = "зарезервированно для ZIGBEE"
DLMS_GATEWAY = "DLMS Gateway"
MANUFACTURER_SPECIFIC = "Спецификация производителя"
A_XDR = "A-XDR кодировка xDLMS APDU"
XML = "XML кодировка xDLMS APDU"
UNCONFIRMED_FAILURE = "Неподтвержденная, повторение при поддержке сбоя на уровне протокола"
UNCONFIRMED_MISSING = "Неподтверждено, повторение пропущенного подтверждения протокола"
CONFIRMED = "подтверждено, повторите пропущенное подтверждение"
MASTER_KEY = "мастер ключ"
GLOB_UNI_ENCR_KEY = "Глобальный ключ шифрования одноадресный"
GLOB_BROAD_ENCR_KEY = "Глобальный ключ шифрования широковещательный"
IDENTIFIED_KEY = "Идентификационный ключ"
WRAPPED_KEY = "Обернутый ключ"
AGREED_KEY = "Согласованный ключ"

# for GSM_diagnostic.cell_info
OR_LESS = "или менее"
OR_GREATER = "или более"
NOT_KNOWN_OR_NOT_DETECTABLE = "не известно или не опознано"
